@@ -18,7 +18,8 @@ from grapl_analyzerlib.nodes.viewable import (
     EdgeViewT,
     ForwardEdgeView,
     ReverseEdgeView,
-    NV)
+    NV,
+)
 
 T = TypeVar("T")
 
@@ -30,7 +31,6 @@ class FileQuery(Queryable["FileView"]):
     def __init__(self,) -> None:
         super(FileQuery, self).__init__(FileView)
         self._file_path = []  # type: List[List[Cmp[str]]]
-        self._asset_id = []  # type: List[List[Cmp[str]]]
         self._file_extension = []  # type: List[List[Cmp[str]]]
         self._file_mime_type = []  # type: List[List[Cmp[str]]]
         self._file_size = []  # type: List[List[Cmp[int]]]
@@ -47,6 +47,8 @@ class FileQuery(Queryable["FileView"]):
         self._sha1_hash = []  # type: List[List[Cmp[str]]]
         self._sha256_hash = []  # type: List[List[Cmp[str]]]
 
+        self._risks = None  # type: Optional['RiskQuery']
+
         self._creator = None  # type: Optional['ProcessQuery']
         self._writers = None  # type: Optional['ProcessQuery']
         self._readers = None  # type: Optional['ProcessQuery']
@@ -75,17 +77,6 @@ class FileQuery(Queryable["FileView"]):
         )
         return self
 
-    def with_asset_id(
-        self: "NQ",
-        eq: Optional["StrCmp"] = None,
-        contains: Optional["StrCmp"] = None,
-        ends_with: Optional["StrCmp"] = None,
-    ) -> "NQ":
-        cast("FileQuery", self)._asset_id.extend(
-            _str_cmps("asset_id", eq, contains, ends_with)
-        )
-        return self
-
     def with_file_extension(
         self: "NQ",
         eq: Optional["StrCmp"] = None,
@@ -337,6 +328,12 @@ class FileQuery(Queryable["FileView"]):
         cast("FileQuery", self)._readers = reader
         return self
 
+    def with_risks(self: "NQ", risks_query: Optional["RiskQuery"] = None) -> "NQ":
+        risks = risks_query or RiskQuery()  # type: RiskQuery
+        risks._risky_nodes = self
+        cast("FileQuery", self)._risks = risks
+        return self
+
     def _get_unique_predicate(self) -> Optional[Tuple[str, "PropertyT"]]:
         return "file_path", str
 
@@ -346,7 +343,6 @@ class FileQuery(Queryable["FileView"]):
     def _get_property_filters(self) -> Mapping[str, "PropertyFilter[Property]"]:
         _prop_filters = {
             "file_path": self._file_path,
-            "asset_id": self._asset_id,
             "file_extension": self._file_extension,
             "file_mime_type": self._file_mime_type,
             "file_size": self._file_size,
@@ -368,7 +364,13 @@ class FileQuery(Queryable["FileView"]):
         return cast("Mapping[str, PropertyFilter[Property]]", prop_filters)
 
     def _get_forward_edges(self) -> Mapping[str, "Queryable"]:
-        return {}
+        forward_edges = {
+            "risks": self._risks,
+        }
+
+        filtered = {re[0]: re[1] for re in forward_edges.items() if re[1] is not None}
+
+        return cast("Mapping[str, Queryable]", filtered)
 
     def _get_reverse_edges(self) -> Mapping[str, Tuple["Queryable", str]]:
         reverse_edges = {
@@ -394,7 +396,6 @@ class FileView(Viewable):
         uid: str,
         node_type: Optional[str] = None,
         file_path: Optional[str] = None,
-        asset_id: Optional[str] = None,
         file_extension: Optional[str] = None,
         file_mime_type: Optional[str] = None,
         file_size: Optional[int] = None,
@@ -415,6 +416,7 @@ class FileView(Viewable):
         readers: Optional[List["ProcessView"]] = None,
         deleter: Optional["ProcessView"] = None,
         spawned_from: Optional[List["ProcessView"]] = None,
+        risks: Optional[List["RiskView"]] = None,
     ) -> None:
         super(FileView, self).__init__(dgraph_client, node_key=node_key, uid=uid)
 
@@ -423,7 +425,6 @@ class FileView(Viewable):
         self.uid = uid
         self.node_type = node_type
         self.file_path = file_path
-        self.asset_id = asset_id
         self.file_extension = file_extension
         self.file_mime_type = file_mime_type
         self.file_size = file_size
@@ -453,9 +454,10 @@ class FileView(Viewable):
         self.readers = readers or []
         self.deleter = deleter
         self.spawned_from = spawned_from or []
+        self.risks = risks or []
 
     def get_node_type(self) -> str:
-        return 'File'
+        return "File"
 
     def get_file_path(self) -> Optional[str]:
         if self.file_path is not None:
@@ -463,12 +465,6 @@ class FileView(Viewable):
         self.file_path = cast(str, self.fetch_property("file_path", str))
         return self.file_path
 
-    def get_asset_id(self) -> Optional[str]:
-        if self.asset_id is not None:
-            return self.asset_id
-        self.asset_id = cast(str, self.fetch_property("asset_id", str))
-        return self.asset_id
-
     def get_file_extension(self) -> Optional[str]:
         if self.file_extension is not None:
             return self.file_extension
@@ -569,8 +565,23 @@ class FileView(Viewable):
         self.sha256_hash = cast(str, self.fetch_property("sha256_hash", str))
         return self.sha256_hash
 
+    def get_risks(self: "NV", match_risks: Optional["IRiskQuery"] = None) -> "List[NV]":
+        _match_risks = match_risks or RiskQuery()  # type: RiskQuery
+
+        self_node = (
+            FileQuery()
+            .with_node_key(eq=self.node_key)
+            .with_risks(_match_risks)
+            .query_first(self.dgraph_client)
+        )
+
+        if self_node:
+            cast(FileView, self).risks = self_node.risks
+
+        return cast(FileView, self).risks
+
     def get_spawned_from(
-            self: "NV", match_spawned_from: Optional["IProcessQuery"] = None
+        self: "NV", match_spawned_from: Optional["IProcessQuery"] = None
     ) -> Optional["NV"]:
         _match_spawned_from = match_spawned_from or ProcessQuery()  # type: ProcessQuery
 
@@ -584,16 +595,16 @@ class FileView(Viewable):
         if self_node:
             cast(FileView, self).spawned_from = self_node.spawned_from
 
-            assert self.node_key == self_node.node_key, 'self and self_node do not have matching node_keys'
+            assert (
+                self.node_key == self_node.node_key
+            ), "self and self_node do not have matching node_keys"
 
         return cast(FileView, self).bin_file
 
-
     @staticmethod
     def _get_property_types() -> Mapping[str, "PropertyT"]:
         return {
             "file_path": str,
-            "asset_id": str,
             "file_extension": str,
             "file_mime_type": str,
             "file_size": int,
@@ -613,7 +624,7 @@ class FileView(Viewable):
 
     @staticmethod
     def _get_forward_edge_types() -> Mapping[str, "EdgeViewT"]:
-        return {}
+        return {"risks": [RiskView]}
 
     @staticmethod
     def _get_reverse_edge_types() -> Mapping[str, Tuple["EdgeViewT", str]]:
@@ -630,7 +641,6 @@ class FileView(Viewable):
             "node_key": self.node_key,
             "uid": self.uid,
             "file_path": self.file_path,
-            "asset_id": self.asset_id,
             "file_extension": self.file_extension,
             "file_mime_type": self.file_mime_type,
             "file_size": self.file_size,
@@ -651,7 +661,14 @@ class FileView(Viewable):
         return {p[0]: p[1] for p in props.items() if p[1] is not None}
 
     def _get_forward_edges(self) -> "Mapping[str, ForwardEdgeView]":
-        return dict()
+        f_edges = {
+            "risks": self.risks,
+        }
+
+        forward_edges = {
+            name: value for name, value in f_edges.items() if value is not None
+        }
+        return cast("Mapping[str, ForwardEdgeView]", forward_edges)
 
     def _get_reverse_edges(self) -> "Mapping[str,  ReverseEdgeView]":
         reverse_edges = {
@@ -669,4 +686,9 @@ class FileView(Viewable):
         return cast("Mapping[str,  ReverseEdgeView]", filtered)
 
 
-from grapl_analyzerlib.nodes.process_node import ProcessQuery, ProcessView, IProcessQuery
+from grapl_analyzerlib.nodes.process_node import (
+    ProcessQuery,
+    ProcessView,
+    IProcessQuery,
+)
+from grapl_analyzerlib.nodes.risk_node import RiskQuery, IRiskQuery, RiskView
