@@ -9,7 +9,7 @@ from grapl_analyzerlib.nodes.viewable import Viewable, NV
 
 T = TypeVar("T")
 
-IProcessQuery = TypeVar("IProcessQuery", bound="ProcessQuery")
+IProcessQuery = TypeVar("IProcessQuery", bound="ProcessQuery[ProcessView]")
 IProcessView = TypeVar("IProcessView", bound="ProcessView")
 
 
@@ -18,7 +18,6 @@ class ProcessQuery(Queryable[IProcessView]):
         super(ProcessQuery, self).__init__(ProcessView)
         self._process_id = []  # type: List[List[Cmp[int]]]
         self._created_timestamp = []  # type: List[List[Cmp[int]]]
-        self._asset_id = []  # type: List[List[Cmp[str]]]
         self._terminate_time = []  # type: List[List[Cmp[int]]]
         self._image_name = []  # type: List[List[Cmp[str]]]
         self._process_name = []  # type: List[List[Cmp[str]]]
@@ -37,8 +36,11 @@ class ProcessQuery(Queryable[IProcessView]):
             None
         )  # type: Optional['IProcessInboundConnectionQuery']
 
+        self._risks = None  # type: Optional['IRiskQuery']
+
         # Reverse edges
         self._parent = None  # type: Optional['ProcessQuery']
+        self._process_asset = None  # type: Optional['AssetQuery']
 
     def with_process_name(
         self: "NQ",
@@ -82,28 +84,6 @@ class ProcessQuery(Queryable[IProcessView]):
         )
         return self
 
-    def with_asset_id(
-        self: "NQ",
-        eq: Optional["StrCmp"] = None,
-        contains: Optional["StrCmp"] = None,
-        ends_with: Optional["StrCmp"] = None,
-        starts_with: Optional["StrCmp"] = None,
-        regexp: Optional["StrCmp"] = None,
-        distance: Optional[Tuple["StrCmp", int]] = None,
-    ) -> "NQ":
-        cast(ProcessQuery, self)._asset_id.extend(
-            _str_cmps(
-                "asset_id",
-                eq=eq,
-                contains=contains,
-                ends_with=ends_with,
-                starts_with=starts_with,
-                regexp=regexp,
-                distance=distance,
-            )
-        )
-        return self
-
     def with_terminate_time(
         self: "NQ",
         eq: Optional["IntCmp"] = None,
@@ -212,9 +192,7 @@ class ProcessQuery(Queryable[IProcessView]):
 
     def with_created_connections(
         self: "NQ",
-        created_connection_query: Optional[
-            "IProcessOutboundConnectionQuery"
-        ] = None,
+        created_connection_query: Optional["IProcessOutboundConnectionQuery"] = None,
     ) -> "NQ":
         from grapl_analyzerlib.nodes.process_outbound_network_connection import (
             ProcessOutboundConnectionQuery,
@@ -229,9 +207,7 @@ class ProcessQuery(Queryable[IProcessView]):
 
     def with_inbound_connections(
         self: "NQ",
-        inbound_connection_query: Optional[
-            "IProcessInboundConnectionQuery"
-        ] = None,
+        inbound_connection_query: Optional["IProcessInboundConnectionQuery"] = None,
     ) -> "NQ":
         from grapl_analyzerlib.nodes.process_inbound_network_connection import (
             ProcessInboundConnectionQuery,
@@ -241,7 +217,13 @@ class ProcessQuery(Queryable[IProcessView]):
             inbound_connection_query or ProcessInboundConnectionQuery()
         )  # type: ProcessInboundConnectionQuery
         inbound_connection._bound_by = self
-        self._inbound_connections = inbound_connection
+        cast("ProcessQuery", self)._inbound_connections = inbound_connection
+        return self
+
+    def with_risks(self: "NQ", risks_query: Optional["RiskQuery"] = None) -> "NQ":
+        risks = risks_query or RiskQuery()  # type: RiskQuery
+        risks._risky_nodes = self
+        cast("ProcessQuery", self)._risks = risks
         return self
 
     def with_parent(self: "NQ", parent_query: Optional["IProcessQuery"] = None) -> "NQ":
@@ -251,6 +233,13 @@ class ProcessQuery(Queryable[IProcessView]):
         cast(ProcessQuery, self)._parent = parent
         return self
 
+    def with_asset(self: "NQ", asset_query: Optional["IAssetQuery"] = None) -> "NQ":
+        asset = asset_query or AssetQuery()  # type: AssetQuery
+
+        asset._asset_processes = cast(ProcessQuery, self)
+        cast(ProcessQuery, self)._process_asset = asset
+        return self
+
     def _get_unique_predicate(self) -> Optional[Tuple[str, "PropertyT"]]:
         return "process_id", int
 
@@ -263,7 +252,6 @@ class ProcessQuery(Queryable[IProcessView]):
             "process_id": self._process_id,
             "process_name": self._process_name,
             "created_timestamp": self._created_timestamp,
-            "asset_id": self._asset_id,
             "terminate_time": self._terminate_time,
             "image_name": self._image_name,
             "arguments": self._arguments,
@@ -275,7 +263,7 @@ class ProcessQuery(Queryable[IProcessView]):
 
         return combined
 
-    def _get_forward_edges(self) -> Mapping[str, "Queryable"]:
+    def _get_forward_edges(self) -> Mapping[str, "Queryable[Viewable]"]:
         forward_edges = {
             "children": self._children,
             "bin_file": self._bin_file,
@@ -285,12 +273,16 @@ class ProcessQuery(Queryable[IProcessView]):
             "wrote_files": self._wrote_files,
             "created_connections": self._created_connections,
             "inbound_connections": self._inbound_connections,
+            "risks": self._risks,
         }
 
         return {fe[0]: fe[1] for fe in forward_edges.items() if fe[1] is not None}
 
-    def _get_reverse_edges(self) -> Mapping[str, Tuple["Queryable", str]]:
-        reverse_edges = {"~children": (self._parent, "parent")}
+    def _get_reverse_edges(self) -> Mapping[str, Tuple["Queryable[Viewable]", str]]:
+        reverse_edges = {
+            "~children": (self._parent, "parent"),
+            "~asset_processes": (self._process_asset, "process_asset"),
+        }
 
         return {
             fe[0]: (fe[1][0], fe[1][1])
@@ -308,7 +300,6 @@ class ProcessView(Viewable):
         node_type: Optional[str] = None,
         process_id: Optional[int] = None,
         created_timestamp: Optional[int] = None,
-        asset_id: Optional[str] = None,
         terminate_time: Optional[int] = None,
         image_name: Optional[str] = None,
         process_name: Optional[str] = None,
@@ -319,19 +310,16 @@ class ProcessView(Viewable):
         read_files: Optional[List["FileView"]] = None,
         wrote_files: Optional[List["FileView"]] = None,
         deleted_files: Optional[List["FileView"]] = None,
-        created_connections: Optional[
-            List["ProcessOutboundConnectionQuery"]
-        ] = None,
-        inbound_connections: Optional[
-            List["ProcessInboundConnectionQuery"]
-        ] = None,
+        created_connections: Optional[List["ProcessOutboundConnectionQuery"]] = None,
+        inbound_connections: Optional[List["ProcessInboundConnectionQuery"]] = None,
         parent: Optional["NV"] = None,
+        process_asset: Optional["AssetView"] = None,
+        risks: Optional[List["RiskView"]] = None,
     ) -> None:
         super(ProcessView, self).__init__(dgraph_client, node_key=node_key, uid=uid)
         self.process_id = process_id
         self.node_type = node_type
         self.created_timestamp = created_timestamp
-        self.asset_id = asset_id
         self.terminate_time = terminate_time
         self.image_name = image_name
         self.process_name = process_name
@@ -345,10 +333,12 @@ class ProcessView(Viewable):
         self.created_connections = created_connections or []
         self.inbound_connections = inbound_connections or []
         self.bin_file = bin_file
+        self.risks = risks or []
         self.parent = parent
+        self.process_asset = process_asset
 
     def get_node_type(self) -> str:
-        return 'Process'
+        return "Process"
 
     def get_process_id(self: "NV") -> Optional[int]:
         if cast(ProcessView, self).process_id is not None:
@@ -374,14 +364,6 @@ class ProcessView(Viewable):
         )
         return cast(ProcessView, self).created_timestamp
 
-    def get_asset_id(self: "NV") -> Optional[str]:
-        if cast(ProcessView, self).asset_id is not None:
-            return cast(ProcessView, self).asset_id
-        cast(ProcessView, self).asset_id = cast(
-            str, self.fetch_property("asset_id", str)
-        )
-        return cast(ProcessView, self).asset_id
-
     def get_terminate_time(self: "NV") -> Optional[int]:
         if cast(ProcessView, self).terminate_time is not None:
             return cast(ProcessView, self).terminate_time
@@ -426,29 +408,21 @@ class ProcessView(Viewable):
 
         return cast(ProcessView, self).children
 
-    def get_created_connections(
-        self: "NV"
-    ) -> "List[ProcessOutboundConnectionView]":
+    def get_created_connections(self: "NV") -> "List[ProcessOutboundConnectionView]":
         from grapl_analyzerlib.nodes.process_outbound_network_connection import (
             ProcessOutboundConnectionView,
         )
 
         cast(ProcessView, self).created_connections = cast(
             List[ProcessOutboundConnectionView],
-            self.fetch_edges(
-                "created_connections", ProcessOutboundConnectionView
-            ),
+            self.fetch_edges("created_connections", ProcessOutboundConnectionView),
         )
         return cast(ProcessView, self).created_connections
 
-    def get_inbound_connections(
-        self: "NV"
-    ) -> "List[ProcessInboundConnectionView]":
+    def get_inbound_connections(self: "NV") -> "List[ProcessInboundConnectionView]":
         cast(ProcessView, self).created_connections = cast(
             List[ProcessInboundConnectionView],
-            self.fetch_edges(
-                "inbound_connections", ProcessInboundConnectionView
-            ),
+            self.fetch_edges("inbound_connections", ProcessInboundConnectionView),
         )
         return cast(ProcessView, self).created_connections
 
@@ -482,21 +456,41 @@ class ProcessView(Viewable):
         )
         return cast(ProcessView, self).deleted_files
 
-    def get_parent(
-        self: "NV", match_parent: Optional["IProcessQuery"] = None
-    ) -> Optional["NV"]:
+    def get_risks(
+        self: "NV", match_risks: Optional["IRiskQuery"] = None
+    ) -> "List[RiskView]":
+        _match_risks = match_risks or RiskQuery()  # type: RiskQuery
+
+        self_node = (
+            ProcessQuery()
+            .with_node_key(eq=self.node_key)
+            .with_risks(_match_risks)
+            .query_first(self.dgraph_client)
+        )
+
+        if self_node:
+            cast(ProcessView, self).risks = self_node.risks
+
+        return cast(ProcessView, self).risks
+
+    def get_parent(self: "NV") -> Optional["NV"]:
         cast(ProcessView, self).parent = cast(
-            List[FileView], self.fetch_edges("~parent", type(self))
+            ProcessView, self.fetch_edge("~children", type(self))
         )
         return cast(ProcessView, self).parent
 
+    def get_asset(self: "NV") -> Optional["AssetView"]:
+        cast(ProcessView, self).process_asset = cast(
+            AssetView, self.fetch_edge("~asset_processes", AssetView)
+        )
+        return cast(ProcessView, self).process_asset
+
     @staticmethod
     def _get_property_types() -> Mapping[str, "PropertyT"]:
         return {
             "process_id": int,
             "process_name": str,
             "created_timestamp": int,
-            "asset_id": str,
             "terminate_time": int,
             "image_name": str,
             "arguments": str,
@@ -513,6 +507,7 @@ class ProcessView(Viewable):
 
         return {
             "children": [ProcessView],
+            "risks": [RiskView],
             "bin_file": FileView,
             "created_files": [FileView],
             "created_connections": [ProcessOutboundConnectionView],
@@ -524,7 +519,10 @@ class ProcessView(Viewable):
 
     @staticmethod
     def _get_reverse_edge_types() -> Mapping[str, Tuple["EdgeViewT", str]]:
-        return {"~children": (ProcessView, "parent")}
+        return {
+            "~children": (ProcessView, "parent"),
+            "~asset_processes": (AssetView, "process_asset"),
+        }
 
     def _get_properties(self, fetch: bool = False) -> Mapping[str, Union[str, int]]:
         # TODO: Fetch it `fetch`
@@ -532,7 +530,6 @@ class ProcessView(Viewable):
             "process_id": self.process_id,
             "process_name": self.process_name,
             "created_timestamp": self.created_timestamp,
-            "asset_id": self.asset_id,
             "terminate_time": self.terminate_time,
             "image_name": self.image_name,
             "arguments": self.arguments,
@@ -562,7 +559,10 @@ class ProcessView(Viewable):
         return cast("Mapping[str, ForwardEdgeView]", forward_edges)
 
     def _get_reverse_edges(self) -> "Mapping[str, ReverseEdgeView]":
-        _reverse_edges = {"~children": (self.parent, "parent")}
+        _reverse_edges = {
+            "~children": (self.parent, "parent"),
+            "~asset_processes": (self.process_asset, "process_asset"),
+        }
 
         reverse_edges = {
             name: value
@@ -587,8 +587,13 @@ from grapl_analyzerlib.nodes.viewable import EdgeViewT, ForwardEdgeView, Reverse
 from grapl_analyzerlib.nodes.process_inbound_network_connection import (
     IProcessInboundConnectionQuery,
     ProcessInboundConnectionView,
-    ProcessInboundConnectionQuery)
+    ProcessInboundConnectionQuery,
+)
 from grapl_analyzerlib.nodes.process_outbound_network_connection import (
     ProcessOutboundConnectionView,
     IProcessOutboundConnectionQuery,
-    ProcessOutboundConnectionQuery)
+    ProcessOutboundConnectionQuery,
+)
+
+from grapl_analyzerlib.nodes.risk_node import RiskQuery, IRiskQuery, RiskView
+from grapl_analyzerlib.nodes.asset_node import AssetView, AssetQuery, IAssetQuery
