@@ -44,9 +44,28 @@ class Queryable(abc.ABC, Generic[NV]):
         )  # type: Dict[str, 'PropertyFilter[Property]']
 
     def extend(self, extended_type: Type[NQ]) -> NQ:
-        return extended_type(self.view_type)
+        extended_self = extended_type(self.view_type)
+        extended_self._node_key = self._node_key
+        extended_self._uid = self._uid
+        extended_self._query_id = self._query_id
+        extended_self.view_type = self.view_type
+        extended_self.dynamic_forward_edge_filters = self.dynamic_forward_edge_filters
+        extended_self.dynamic_reverse_edge_filters = self.dynamic_reverse_edge_filters
+        extended_self.dynamic_property_filters = self.dynamic_property_filters
 
-    def with_node_key(self: 'NQ', eq: str) -> 'NQ':
+        for prop_filter in self._get_property_filters().items():
+            setattr(extended_self, "_" + prop_filter[0], prop_filter[1])
+
+        for f_edge_filter in self._get_forward_edges().items():
+            setattr(extended_self, "_" + f_edge_filter[0], f_edge_filter[1])
+
+        for r_edge_filter in self._get_reverse_edges().values():
+            setattr(extended_self, "_" + r_edge_filter[1], r_edge_filter[0])
+
+        # We need to add any other queries for this node
+        return extended_self
+
+    def with_node_key(self: "NQ", eq: str) -> "NQ":
         self._node_key = [[Eq("node_key", eq)]]
         return self
 
@@ -86,16 +105,20 @@ class Queryable(abc.ABC, Generic[NV]):
         return {**reverse_edges, **self.dynamic_reverse_edge_filters}
 
     def get_edge_filters(
-        self
+        self,
     ) -> Mapping[str, Union["Queryable", Tuple["Queryable", str]]]:
         return {**self.get_forward_edges(), **self.get_reverse_edges()}
 
     def get_property_filters(self) -> Mapping[str, "PropertyFilter[Property]"]:
         prop_filters = self._get_property_filters()
-        if not prop_filters.get('node_key'):
-            prop_filters['node_key'] = self._node_key
 
-        return {**prop_filters, **self.dynamic_property_filters}
+        return {
+            "node_key": self._node_key,
+            # prop_filters might have its own node_key, which will
+            # overwrite the above one.
+            **prop_filters,
+            **self.dynamic_property_filters,
+        }
 
     def get_property_names(self) -> List[str]:
         prop_names = [
@@ -170,16 +193,13 @@ class Queryable(abc.ABC, Generic[NV]):
 
     @retry(delay=0.05)
     def get_count(
-        self,
-        dgraph_client: DgraphClient,
-        first: Optional[int] = None,
-        contains_node_key: Optional[str] = None,
+        self, dgraph_client: DgraphClient, first: Optional[int] = None,
     ) -> int:
         query_str = generate_query(
             query_name="res",
             binding_modifier="res",
             root=self,
-            contains_node_key=contains_node_key,
+            contains_node_key=None,
             first=first,
             count=True,
         )
@@ -577,4 +597,4 @@ def generate_query(
 from grapl_analyzerlib.nodes.comparators import Has, Cmp, PropertyFilter, Eq
 
 from grapl_analyzerlib.nodes.types import PropertyT, Property
-from grapl_analyzerlib.nodes.viewable import Viewable, NV
+from grapl_analyzerlib.nodes.viewable import Viewable
