@@ -2,7 +2,7 @@ from grapl_analyzerlib.schemas.schema_builder import NodeSchema, ManyToOne
 
 
 class NetworkConnectionSchema(NodeSchema):
-    def __init__(self):
+    def __init__(self) -> None:
         super(NetworkConnectionSchema, self).__init__()
         (
             self.with_str_prop("src_ip_address")
@@ -13,7 +13,7 @@ class NetworkConnectionSchema(NodeSchema):
             .with_int_prop("terminated_timestamp")
             .with_int_prop("last_seen_timestamp")
             .with_forward_edge(
-                "inbound_connection_to",
+                "inbound_network_connection_to",
                 ManyToOne(IpPortSchema),
                 "network_connections_from",
             )
