@@ -2,7 +2,7 @@ from grapl_analyzerlib.schemas.schema_builder import NodeSchema, ManyToMany
 
 
 class ProcessInboundConnectionSchema(NodeSchema):
-    def __init__(self):
+    def __init__(self) -> None:
         super(ProcessInboundConnectionSchema, self).__init__()
         (
             self.with_str_prop("ip_address")
